@@ -17,25 +17,25 @@ start_shell_str = command_args.start_shell_str
 script_name = command_args.script_name
 
 
-
 def restart(args=None):
-    threading.Thread(target=os.system, args=(start_shell_str,)).start()
-
+    kill_str = f'''ps -aux|grep {script_name} |grep -v grep|awk '{{print $2}}' |xargs kill -9;'''
+    threading.Thread(target=os.system, args=(kill_str + start_shell_str,)).start()
     while True:
         time.sleep(20)
         try:
             r1 = subprocess.getstatusoutput('git pull')
             print(r1[1])
-            if 'Already up-to-date' in r1[1]:
+            if 'Already up-to-date' in r1[1] or '已经是最新的' in r1[1]:
                 print('no update')
                 continue
         except Exception as e:  # 只要不在205的dev分支手动修改文件，一般不会出现拉取报错。
-            subprocess.getstatusoutput(f'''ps -aux|grep {script_name} |grep -v grep|awk '{{print $2}}' |xargs kill -9''')
+            subprocess.getstatusoutput(kill_str)
             print(e)
             break
         # subprocess.getstatusoutput(cmd_str)
-        threading.Thread(target=os.system, args=(start_shell_str,)).start()
+        print('git内容更新了，执行语句：', kill_str, start_shell_str)
+        threading.Thread(target=os.system, args=(kill_str + start_shell_str,)).start()
 
 
 if __name__ == '__main__':
-    restart()
\ No newline at end of file
+    restart()
